@@ -2,12 +2,13 @@
 # Copyright 2013 Christopher Foo <chris.foo@gmail.com>
 # Licensed under GPLv3. See COPYING.txt for details.
 import collections
+import datetime
+import email.utils
 import hashlib
 import http.client
 import io
 import logging
 import os
-import string
 import tempfile
 import threading
 import urllib.parse
@@ -221,10 +222,12 @@ class FileCache(object):
             self._files.append((filename, file_obj))
 
 
-def copyfile_obj(source, dest, bufsize=4096, max_length=None):
+def copyfile_obj(source, dest, bufsize=4096, max_length=None,
+write_attr_name='write'):
     '''Like :func:`shutil.copyfileobj` but with limit on how much to copy'''
 
     bytes_read = 0
+    write_func = getattr(dest, write_attr_name)
 
     while True:
         if max_length != None:
@@ -237,7 +240,7 @@ def copyfile_obj(source, dest, bufsize=4096, max_length=None):
         if not data:
             break
 
-        dest.write(data)
+        write_func(data)
         bytes_read += len(data)
 
 
@@ -326,5 +329,18 @@ def rename_filename_dirs(dest_filename):
             break
 
 
+def parse_http_date(s):
+    t = email.utils.parsedate_tz(s)
+
+    if not t:
+        raise ValueError('Unable to parse date')
+
+    tzinfo = datetime.timezone(datetime.timedelta(seconds=t[9]))
+    d = datetime.datetime(*t[:6], tzinfo=tzinfo)
+
+    return d
+
+
+
 file_cache = FileCache()
 '''The :class:`FileCache` instance'''
